@@ -1,6 +1,7 @@
 import logging
 import time
 import warnings
+from copy import copy
 from uuid import uuid4
 
 import attr
@@ -90,6 +91,12 @@ class Recipe(object):
 
         self.stats = Stats()
 
+        # Store the original dimensions and metrics put into the recipe.
+        # These may contain duplicates, which will not exist after the
+        # ingredients are added to the cauldron.
+        self.raw_metrics = tuple()
+        self.raw_dimensions = tuple()
+
         if metrics is not None:
             self.metrics(*metrics)
         if dimensions is not None:
@@ -233,13 +240,13 @@ class Recipe(object):
 
     @recipe_arg()
     def cache_region(self, value):
-        """Set a cache region for recipe-caching to use """
+        """Set a cache region for recipe-caching to use"""
         assert isinstance(value, str)
         self._cache_region = value
 
     @recipe_arg()
     def cache_prefix(self, value):
-        """Set a cache prefix for recipe-caching to use """
+        """Set a cache prefix for recipe-caching to use"""
         assert isinstance(value, str)
         self._cache_prefix = value
 
@@ -251,7 +258,7 @@ class Recipe(object):
 
     @recipe_arg()
     def shelf(self, shelf=None):
-        """ Defines a shelf to use for this recipe """
+        """Defines a shelf to use for this recipe"""
         if shelf is None:
             self._shelf = Shelf({})
         elif isinstance(shelf, Shelf):
@@ -277,6 +284,7 @@ class Recipe(object):
                          Metric objects
         :type metrics: list
         """
+        self.raw_metrics = self.raw_metrics + copy(metrics)
         for m in metrics:
             self._cauldron.use(self._shelf.find(m, Metric))
 
@@ -293,6 +301,7 @@ class Recipe(object):
                          Dimension objects
         :type dimensions: list
         """
+        self.raw_dimensions = self.raw_dimensions + copy(dimensions)
         for d in dimensions:
             self._cauldron.use(self._shelf.find(d, Dimension))
 
@@ -372,7 +381,7 @@ class Recipe(object):
     # ------
 
     def _is_postgres(self):
-        """ Determine if the running engine is postgres """
+        """Determine if the running engine is postgres"""
         try:
             driver = self._session.bind.url.drivername
             if "redshift" in driver or "postg" in driver or "pg" in driver:
